package com.abi.qms.platform.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import com.abi.qms.platform.dao.entity.BaseSapSku;
import com.abi.qms.platform.dao.mapper.BaseSapSkuMapper;
import com.abi.qms.platform.dto.req.BatchImportSkuReq;
import com.abi.qms.platform.service.BaseSapSkuService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author: fangxinjian
 * @date: 2021/06/02 09:38
 * @description:
 */
@Service
@Slf4j
public class BaseSapSkuServiceImpl implements BaseSapSkuService {

    @Autowired
    private BaseSapSkuMapper baseSapSkuMapper;


    @Override
    public void batchImportSku(BatchImportSkuReq req) {
        List<BatchImportSkuReq.SapSkuBean> sapSkuBeanList = req.getSapSkuBeanList();

        for (BatchImportSkuReq.SapSkuBean sku : sapSkuBeanList) {

            try {
                //申明对象
                BaseSapSku sapSku = new BaseSapSku();
                sapSku.setId(sku.getId());
                sapSku.setBrandCode(sku.getBrandCode());
                sapSku.setSubBrandCode(sku.getSubBrandCode());
                sapSku.setSkuCode(sku.getSkuCode());
                sapSku.setSkuName(sku.getSkuName());
                sapSku.setSkuType(sku.getSkuType());

                saveBaseSapSku(sapSku);
            } catch (Exception e) {
                log.error("导入SKU数据失败", e);
            }
        }
    }

    public void saveBaseSapSku(BaseSapSku bss) {

        //校验入参 code不能重复
        QueryWrapper<BaseSapSku> qw = new QueryWrapper<>();
        qw.eq("sku_code", bss.getSkuCode());
        if (bss.getId() != null) {
            qw.ne("id", bss.getId());
        }
        List<BaseSapSku> sapSkuList = baseSapSkuMapper.selectList(qw);
        if (CollectionUtil.isNotEmpty(sapSkuList)) {
            log.info("SKU ID:{}已存在", bss.getSkuCode());
        }

        if (bss.getId() != null) {
            BaseSapSku baseSapSku = baseSapSkuMapper.selectById(bss.getId());
            if (ObjectUtil.isNull(baseSapSku)) {
                log.info("SKU不存在:{}不存在", bss.getSkuCode());
            }
        }

        //新增or修改
        if (bss.getId() != null) {
            baseSapSkuMapper.updateById(bss);
        } else {
            baseSapSkuMapper.insert(bss);
        }

    }

}
